{ inputs, config, pkgs, ... }:
let
    fzgo_paths = {
        files = [
            "/home/user/.dotfiles"
            "/home/server/.cache/fzgo/entries/f/|home|user|Workspace"
        ];
        dirs = [
            "/home/user/.dotfiles"
            "/home/server/.cache/fzgo/entries/d/|home|user|Workspace"
            "/home/server/.cache/fzgo/entries/d/|home|server|Storage|Thomas"
            "/home/server/.cache/fzgo/entries/d/|home|server|Storage|Shared"
        ];
    };
in
{
    imports = [
        (import ./utils/desktop.nix { inherit inputs config pkgs; })
        (import ./utils/fzgo_links.nix { inherit config pkgs fzgo_paths; })
    ];

    programs.ssh.matchBlocks."*".identityFile = "/home/user/.secrets/SSH/Aloria/id_ed25519";

    home.packages = with pkgs; [
        jetbrains.pycharm-professional
        distrobox
        gnome-disk-utility
        moonlight-qt
        vscode
        texliveFull
        gnome-power-manager
        discord
        smile
    ];

    services.hyprpaper = {
        settings = {
            wallpaper = [
                "HDMI-A-1,${./hyprland/files/wallpaper.png}"
                "DP-1,${./hyprland/files/wallpaper.png}"
                "eDP-1,${./hyprland/files/wallpaper.png}"
            ];
        };
    };

    wayland.windowManager.hyprland.settings = {
        monitor = [
            "eDP-1,2880x1800@120.00Hz,0x0,1.2"
            "DP-1,3840x2160@60.00Hz,0x-2160,1"
            "HDMI-A-1,3840x2160@60.00Hz,0x-2160,1"
        ];
        bind = [
            ", XF86PowerOff, exec, ${pkgs.rofi}/bin/rofi -show power-menu -modi power-menu:${
            ./hyprland/files/rofi-power-menu.sh
        }"
        ];
        general.gaps_out = 1;
    };

    programs.alacritty.settings.font.size = 16;
    programs.kitty.font.size = 15;
}
