{ inputs, config, pkgs, ... }:
let
    fzgo_paths = {
        files = [
            "/home/user/.dotfiles"
            "/home/server/.cache/fzgo/entries/f/|home|user|Workspace"
        ];
        dirs = [
            "/home/user/.dotfiles"
            "/home/server/.cache/fzgo/entries/d/|home|user|Workspace"
            "/home/server/.cache/fzgo/entries/d/|home|server|Storage|Thomas"
            "/home/server/.cache/fzgo/entries/d/|home|server|Storage|Shared"
        ];
    };
in
{
    imports = [
        (import ./utils/desktop.nix { inherit inputs config pkgs; })
        (import ./utils/fzgo_links.nix { inherit config pkgs fzgo_paths; })
    ];
    programs.ssh.matchBlocks."*".identityFile = "/home/user/.secrets/SSH/Kell/id_ed25519";

    dconf.settings = {
        "org/virt-manager/virt-manager/connections" = {
            autoconnect = ["qemu:///system"];
            uris = ["qemu:///system"];
        };
    };

    home.packages = with pkgs; [
        distrobox
        gnome-disk-utility
        moonlight-qt
        vscode
        jetbrains.rider
        discord
    ];

    services.hyprpaper = {
        settings = {
            wallpaper = [
                "DP-1,${./hyprland/files/wallpaper.png}"
                "DP-2,${./hyprland/files/wallpaper.png}"
                "HDMI-A-1,${./hyprland/files/wallpaper.png}"
            ];
        };
    };
    wayland.windowManager.hyprland.settings = {
        monitor = [
            "DP-2,preferred,0x550,1"
            "DP-1,preferred,1920x0,1"
            "HDMI-A-1,preferred,5760x550,1"
        ];
        input.kb_options = "compose:rctrl, caps:super, altwin:swap_alt_win";
        # input.kb_options = "compose:rctrl, caps:super";
    };
}
