{ inputs, config, pkgs, ... }:
let
in
    {
    home.username = "user";
    home.homeDirectory = "/home/user";
    nix = {
        package = pkgs.nix;
        settings.use-xdg-base-directories = true;
    };

    xdg.enable = true;

    imports = [
        (import ./utils/common.nix { inherit inputs config pkgs; })
        ./ssh
    ];
    programs.ssh.matchBlocks."*".identityFile = "/home/user/.secrets/SSH/Pi/id_ed25519";

    home.sessionVariables = {
        NIX_PATH = "${config.xdg.stateHome}/nix/profiles/channels/";
        LANG = "en_US.UTF-8";
        XDG_RUNTIME_DIR = "/run/user/$(id -u)";
    };

    programs.zsh.initContent = pkgs.lib.mkAfter ''
      LOCAL_SEARCH_DIRS=(~/.dotfiles/)
      REMOTE_SEARCH_DIRS=()
      if [ -e '/nix/var/nix/profiles/default/etc/profile.d/nix-daemon.sh' ]; then
          . '/nix/var/nix/profiles/default/etc/profile.d/nix-daemon.sh'
      fi
    '';
}
