{ inputs, config, pkgs, ... }:
let
    fzgo_paths = {
        files = [
            "/home/user/.dotfiles"
            "/home/server/.cache/fzgo/entries/f/|home|user|Workspace"
        ];
        dirs = [
            "/home/user/.dotfiles"
            "/home/server/.cache/fzgo/entries/d/|home|user|Workspace"
            "/home/server/.cache/fzgo/entries/d/|home|server|Storage|Thomas"
            "/home/server/.cache/fzgo/entries/d/|home|server|Storage|Shared"
        ];
    };
in
{
    imports = [
        (import ./utils/fzgo_links.nix { inherit config pkgs fzgo_paths; })
        (import ./utils/desktop.nix { inherit inputs config pkgs; })
        ./ssh
    ];

    programs.ssh.matchBlocks."*".identityFile = "/home/user/.secrets/SSH/Riva/id_ed25519";

    home.packages = with pkgs; [
        distrobox
        jq
        rclone
    ];
    services.hyprpaper = {
        settings = {
            wallpaper = [
                "Virtual-1,${./hyprland/files/wallpaper.png}"
            ];
        };
    };
    wayland.windowManager.hyprland.settings = {
        monitor = [
            "Virtual-1,2560x1440,0x0,1"
        ];
        input.kb_options = "compose:rctrl, caps:super, altwin:swap_alt_win";
    };
}
