{ inputs, config, pkgs, ... }:

{
    home.username = "user";
    home.homeDirectory = "/home/user";
    nix = {
        package = pkgs.nix;
        settings = {
            trusted-users = [ "user" ];
            use-xdg-base-directories = true;
        };
    };

    xdg.enable = true;
    imports = [
        (import ./utils/common.nix { inherit inputs config pkgs; })
        ./alacritty
        ./ssh
    ];

    programs.ssh.matchBlocks."*".identityFile = "/home/user/.secrets/SSH/Tolnedra/id_ed25519";

    home.packages = with pkgs; [
        wl-clipboard
        jq
    ];

    home.sessionVariables = {
        NIX_PATH = "${config.xdg.stateHome}/nix/profiles/channels/";
        LANG = "en_US.UTF-8";
        XDG_RUNTIME_DIR = "/run/user/$(id -u)";
    };

    programs.zsh.initContent = pkgs.lib.mkAfter ''
      LOCAL_SEARCH_DIRS=(~/.dotfiles/)
      REMOTE_SEARCH_DIRS=()
    '';

    programs.alacritty.settings.window.opacity = 0.8;
}
