{ inputs, config, pkgs, ... }:

{
    imports = [
        (import ../zsh { inherit inputs config pkgs; })
        (import ../bash { inherit inputs config pkgs; })
        ../git
        ../nvim
        ../email
        ../lf
        ../tmux
        ../yazi
        ../zellij
    ];

    home.stateVersion = "24.11";
    targets.genericLinux.enable = true;
    programs.home-manager.enable = true;
    home.packages = with pkgs; [
        htop
        waypipe
        inputs.worktimer.packages.${pkgs.system}.default
        usbutils
    ];
    programs.nh = {
        enable = true;
        clean.enable = true;
        flake = "/home/user/.dotfiles";
    };

    home.sessionVariables = {
        XDG_CONFIG_HOME = "${config.xdg.configHome}";
        XDG_CACHE_HOME = "${config.xdg.cacheHome}";
        XDG_DATA_HOME = "${config.xdg.dataHome}";
        XDG_STATE_HOME = "${config.xdg.stateHome}";

        CUDA_CACHE_PATH = "${config.xdg.cacheHome}/nv";
        DOCKER_CONFIG = "${config.xdg.configHome}/docker";
        LESSHISTFILE = "${config.xdg.cacheHome}/less/history";
        PARALLEL_HOME = "${config.xdg.configHome}/parallel";
        PYTHONSTARTUP = "${config.xdg.configHome}/python/pythonrc";
        SQLITE_HISTORY = "${config.xdg.cacheHome}/sqlite_history";
        WINEPREFIX = "${config.xdg.dataHome}/wine";
        # XDG_CURRENT_DESKTOP = "GNOME";
        OPENCV_LOG_LEVEL = "ERROR";
        COLORTERM = "truecolor";
    };

    home.file.".latexmkrc".text = ''
      $pdf_mode = 1;
      $pdf_previewer = 'evince %O %S';
    '';

}
