{ inputs, config, pkgs, ... }:
{
    imports = [
        (import ../Common/default.nix { inherit inputs config pkgs; })
        (import ../Common/desktop.nix { inherit inputs pkgs config; })
        (import ../Common/nvidia.nix { inherit pkgs config; })
    ];

    boot.kernelPackages = pkgs.linuxPackages_latest;
    services.ollama = {
        enable = true;
    };

    services.sunshine = {
        enable = true;
        autoStart = false;
        capSysAdmin = true;
        openFirewall = true;
    };

    boot.kernelParams = ["mitigations=off"];

    zramSwap.enable = true;
    networking.wg-quick.interfaces = {
        wg0 = {
            address = [ "10.0.0.12/24" ];
            privateKeyFile = "/home/user/.secrets/Wireguard/Riva.key";
            listenPort = 51820;
            peers = [{
                publicKey = "/9ppjm3yeD0duDvxrqgcHscHmftXko+0s2RbivNEy2c=";
                allowedIPs = [ "10.0.0.1/8" ];
                endpoint = "192.168.1.1:13231";
            }];
        };
    };
    fileSystems."/home/server/Workspace" = {
        device = "/mnt/Workspace";
        fsType = "virtiofs";
    };
    fileSystems."/home/server/.cache/fzgo" = {
        device = "/mnt/fzgo_cache";
        fsType = "virtiofs";
    };
    fileSystems."/home/user/Workspace" = {
        device = "/home/server/Workspace";
        options = ["bind"];
    };
    services.resolved = {
        enable = false;
    };
    networking.nameservers = ["192.168.1.2"];
    programs.steam = {
        enable = true;
        gamescopeSession.enable = true;
    };
}
